//An M/M/1 System Example
//Written by: Minh Viet Le - Monash University - January 13, 2006
//Email: minh.leviet@infotech.monash.edu.au

//Problem Statement

//Customers arrive at a bank with a mean arrival rate lamda (e.g. 24 per hour -> lamda=24). 
//A customer is served with a mean service time of k hours, for example k=0.5 (hours) ~ 30 minutes
//(i.e. 1/k=2 is the average service rate of customers (muy) in one hour).

//Determine 
//(a) What is the average number of customers in the bank?
//(b) The average time a customer spends in the bank. In other words, how much time should 
// a customer expect to spend in the bank?
//(b) What is the probability that a customer will wait more than t hours for a service?
//(d) The average number of customers waiting to be served.

//Descriptions/assumptions of The solution
 
//Let lamda be the average customer arrival in per unit time (e.g. hour, minute, second).
//Let muy be the average service rate of customers (i.e. the number of customers served per unit time).

//Therefore, the expected interarrival time and the expected time to serve one customer 
//are 1/lamda and 1/muy, respectively.

//Let pro be the traffic intensity (or the ultilisation factor) 
//			pro=lamda/muy

//Let L  be the average number of customers in the system.
//Let Lq be the average length of the queue (i.e. the average number of customers waiting to be served).
//Let W  be the average time a customer is expected to spend in the system.

//Let PSt be the probability that a customer spends more than t units of time in the system (bank).
//Let PQt be the probability that a customer spends more than t units of time in the queue.

//Assuming all the assumptions are met.

#include<stdio.h>
#include<math.h>

int main(int argc, char* argv[])
{
	float lamda=0, muy=0, pro=0;
	float L=0, Lq, W=0, t=0;

	float PQt=0, PSt=0, temp=0;

	printf("An M/M/1 System Example.\n");
	printf("Assuming time units in hour.\n");
	
	printf("Enter the average customer arrival in one hour: ");
	scanf("%f",&lamda);

	printf("Enter the average service rate of customers in one hour e.g. 6 customers/1hr: ");
	scanf("%f",&muy);

	printf("Enter the maximum time the customer could tolerate the system (to find out its probability): ");
	scanf("%f",&t);

	pro=(float)(lamda/muy);

	if (pro > 1)
	{
		printf("The system is not stable due to the arrivals come at \n");
		printf("a faster rate than the server can accommodate. \n");
		return(1);
	}
	else
	{
		L=(float)(pro/(1-pro));			//The average number of customers in the bank.

		Lq=(float) pow(pro,2)/(1-pro);	//The average number of customers in the queue.

		W=(float)(1/(muy-lamda));		//The average time a customer expects to spend in the bank.

		PSt=(float)(exp(-t/W));			//The probability that a customer spends more than t hours in the bank.

		PQt= (float)(pro * exp(-t/W));	//The probability that a customer spends more than t hours in the queue.
		
		printf("The traffic intensity (or the ultilisation factor) pro is %.3f\n",pro);

		printf("The average number of customers in the bank is %.3f\n",L);
	
		printf("The average time a customer expects to spend in the bank is %.5f (hours)\n",W);

		printf("The probability that a customer spends more than %.3f hour(s) in the system (bank) is %.5f\n",t,PSt);

		printf("The probability that a customer spends more than %.3f hour(s) in the queue is %.5f\n",t,PQt);

		printf("The average number of customers waiting to be served (the average length of the queue) is %.3f\n",Lq);
	}
	
	return 0;

}

